﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Diagnostics;
using System.Timers;
using System.Windows.Threading;

namespace MIXer.Customization
{
    public class EventDelayAggregator
    {
        #region Fields
        private Timer _timer = null;
        private Dispatcher _dispatcher = null;
        #endregion

        #region Constructors
        public EventDelayAggregator(Action callback)
            : this(500, callback) // 1/2 second
        {
        }
        public EventDelayAggregator(int delay, Action callback)
        {
            if (callback == null)
                throw new ArgumentNullException("callback");

            _dispatcher = Dispatcher.CurrentDispatcher;
            _timer = new Timer(delay);
            _timer.Elapsed += (sender, args) =>
            {
                Stop();
                _dispatcher.Invoke(callback, DispatcherPriority.Render);
            };
        }
        #endregion

        #region Methods
        public void Start()
        {
            if (_timer == null)
                throw new InvalidOperationException("Timer wasn't correctly initiated");

            IsStarted = true;
            _timer.Start();
        }
        public void Stop()
        {
            if (_timer == null)
                throw new InvalidOperationException("Timer wasn't correctly initiated");

            IsStarted = false;
            _timer.Stop();
        }
        public void Signal()
        {
            if (_timer == null)
                throw new InvalidOperationException("Timer wasn't correctly initiated");

            if (!IsStarted)
            {
                Start();
            }
            else
            {
                _timer.Stop();
                _timer.Start();
            }
        }
        #endregion

        #region Properties
        public bool IsStarted { get; private set; }
        #endregion
    }
}
